pub struct CielabColor {
pub l: f32,
pub a: f32,
pub b: f32,
}Expand description
CIELAB color for perceptually uniform gradients.
CIELAB (Lab*) is designed so that equal distances in the color space correspond to equal perceived color differences.
Example
ⓘ
use probar::brick::tui::CielabColor;
// Create gradient from green (0%) to red (100%)
let green = CielabColor::percent_gradient(0.0);
let red = CielabColor::percent_gradient(1.0);
// Interpolate for 50%
let yellow = green.lerp(&red, 0.5);Fields
l: f32Lightness (0-100)
a: f32Green-red axis (approx -128 to 127)
b: f32Blue-yellow axis (approx -128 to 127)
Implementations
Sourceimpl CielabColor
impl CielabColor
Sourcepub fn to_rgb(&self) -> (u8, u8, u8)
pub fn to_rgb(&self) -> (u8, u8, u8)
Convert to approximate sRGB (0-255).
Note: This is a simplified conversion. For accurate results, use a proper color management library.
Sourcepub fn percent_gradient(percent: f32) -> Self
pub fn percent_gradient(percent: f32) -> Self
Create perceptually uniform gradient from green to red.
Uses green -> yellow -> red transition in CIELAB space.
Sourcepub fn meter_gradient(level: f32) -> Self
pub fn meter_gradient(level: f32) -> Self
Create gradient for meter display (blue -> green -> yellow -> red).