pub struct LineCoverage {
pub passed_executions: usize,
pub failed_executions: usize,
}Expand description
Coverage data for a single line
Fields
passed_executions: usizeNumber of times this line was executed in passing tests
failed_executions: usizeNumber of times this line was executed in failing tests