pub struct AudioEmulator { /* private fields */ }Expand description
Implementations
Sourceimpl AudioEmulator
impl AudioEmulator
Sourcepub fn new(source: AudioSource) -> Self
pub fn new(source: AudioSource) -> Self
Create a new audio emulator with the given source
Sourcepub fn with_config(source: AudioSource, config: AudioEmulatorConfig) -> Self
pub fn with_config(source: AudioSource, config: AudioEmulatorConfig) -> Self
Create with custom configuration
Sourcepub fn sample_rate(&self) -> u32
pub fn sample_rate(&self) -> u32
Get the configured sample rate
Sourcepub fn samples_generated(&self) -> u64
pub fn samples_generated(&self) -> u64
Get the number of samples generated so far
Sourcepub fn generate_samples(&mut self, duration_seconds: f32) -> Vec<f32>
pub fn generate_samples(&mut self, duration_seconds: f32) -> Vec<f32>
Generate samples for the specified duration in seconds
Sourcepub fn generate_n_samples(&mut self, num_samples: usize) -> Vec<f32>
pub fn generate_n_samples(&mut self, num_samples: usize) -> Vec<f32>
Generate exactly N samples
Sourcepub fn generate_mock_js(&self, samples: &[f32]) -> String
pub fn generate_mock_js(&self, samples: &[f32]) -> String
Generate JavaScript code to inject into page for mocking getUserMedia