pub struct SimpleFixture { /* private fields */ }Expand description
A simple fixture that executes closures for setup and teardown.
Useful for quick fixture creation without implementing the trait.
Implementations
Sourceimpl SimpleFixture
impl SimpleFixture
Sourcepub fn with_setup<F>(self, f: F) -> Self
pub fn with_setup<F>(self, f: F) -> Self
Set the setup function.
Sourcepub fn with_teardown<F>(self, f: F) -> Self
pub fn with_teardown<F>(self, f: F) -> Self
Set the teardown function.
Sourcepub fn with_priority(self, priority: i32) -> Self
pub fn with_priority(self, priority: i32) -> Self
Set the priority.