TuiTestBackend

Struct TuiTestBackend 

pub struct TuiTestBackend { /* private fields */ }
TUI Test Backend for capturing frames

Provides a text grid and frame capture functionality for testing terminal UIs. Uses TextGrid instead of ratatui::Buffer for zero external dependencies.

Implementations

Source

impl TuiTestBackend

pub fn new(width: u16, height: u16) -> Self

Create a new test backend with the given dimensions

pub fn size(&self) -> (u16, u16)

Get the backend dimensions

pub fn grid(&self) -> &TextGrid

Get a reference to the underlying grid

pub fn grid_mut(&mut self) -> &mut TextGrid

Get a mutable reference to the underlying grid

pub fn capture_frame(&mut self) -> TuiFrame

Capture the current frame

pub fn current_frame(&self) -> TuiFrame

Get the current frame without storing it

pub fn frames(&self) -> &[TuiFrame]

Get all captured frames

pub fn frame_count(&self) -> usize

Get the number of captured frames

pub fn clear(&mut self)

Clear the grid

pub fn reset(&mut self)

Reset the backend (clear grid and frames)

pub fn resize(&mut self, width: u16, height: u16)

Resize the backend

pub fn write_text(&mut self, x: u16, y: u16, text: &str)

Write text at a position (for testing)

pub fn write_lines(&mut self, x: u16, y: u16, lines: &[&str])

Write multiple lines starting at a position